#!perl

use 5.010001;
use strict;
use warnings;

use Test::More 0.98;

# XXX test opt:coerce_from
# XXX test opt:coerce_from unknown module
# XXX test opt:dont_coerce_from
# XXX test opt:done_coerce_from unknown module

ok 1;
done_testing;
